@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afuser.c,v 1.8 2001/05/04 12:37:43 bazsi Exp $
+ * $Id: afuser.c,v 1.9 2003/01/31 14:26:48 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -36,30 +36,65 @@
 #include <utmp.h>
 
 #include "afuser.c.x"
+#include "macros.h"
 
 /* CLASS:
    (class
      (name afuser_dest)
      (super log_dest_driver)
      (vars
-       (username string)))
+       (username string)
+       (template_output string)
+       (template_escape . int)
+       (cfg object syslog_config)))
 */
 
+void
+afuser_dest_set_template(struct log_dest_driver *c, char *t)
+{
+	CAST(afuser_dest, self, c);
+ 
+	self->template_output = c_format("%z", t);
+}
+
+void
+afuser_dest_set_template_escape(struct log_dest_driver *c, int enable)
+{
+	CAST(afuser_dest, self, c);
+
+	self->template_escape = enable;
+}
+
 static int 
 do_init_afuser_dest(struct log_handler *c, 
 		    struct syslog_config *cfg, 
 		    struct persistent_config *persistent)
 {
+	CAST(afuser_dest, self, c);
+
+	self->cfg = cfg;
+
 	return ST_OK | ST_GOON;
 }
 
-static void do_handle_afuser_log(struct log_handler *c, struct log_info *msg)
+static void
+do_handle_afuser_log(struct log_handler *c, struct log_info *msg)
 {
 	CAST(afuser_dest, self, c);
 	struct utmp *ut;
 	struct ol_string *msg_line;
 
-	msg_line = c_format("%S %S %S\n", msg->date, msg->host, msg->msg);
+	if (self->template_output) {
+		msg_line = c_format("%fS",
+				    expand_macros(
+					    self->cfg,
+					    self->template_output,
+					    self->template_escape, msg));
+	} else {
+		msg_line = c_format("%S %S %S\n",
+				    msg->date, msg->host, msg->msg);
+	}
+
 	while ((ut = getutent())) {
 #if HAVE_MODERN_UTMP
 		if (ut->ut_type == USER_PROCESS &&
