@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: destinations.h,v 1.12 2001/02/24 12:38:03 bazsi Exp $
+ * $Id: destinations.h,v 1.13 2002/10/18 12:31:08 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -39,7 +39,7 @@
        (name log_dest_driver)
        (super log_handler)
        (vars
-         (log_fifo_size simple UINT32)
+         (log_fifo_size simple int)
          (next_driver object log_dest_driver)))
 */
 
