@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: filters.c,v 1.16 2002/02/04 16:07:50 bazsi Exp $
+ * $Id: filters.c,v 1.17.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -34,6 +34,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <string.h>
 
 #define CLASS_DEFINE
 #include "filters.h.x"
@@ -189,7 +190,7 @@ static int do_filter_host(struct filter_expr_node *c,
 			  struct log_info *log)
 {
 	CAST(filter_expr_re, self, c);
-	return (!regexec(&self->regex, log->host->data, 0, NULL, 0)) ^ c->comp;
+	return (!regexec(&self->regex, (char *) log->host->data, 0, NULL, 0)) ^ c->comp;
 }
 
 struct filter_expr_node *make_filter_host(const char *re)
@@ -209,7 +210,7 @@ static int do_filter_match(struct filter_expr_node *c,
 			   struct log_info *log)
 {
 	CAST(filter_expr_re, self, c);
-	return (!regexec(&self->regex, log->msg->data, 0, NULL, 0)) ^ c->comp;
+	return (!regexec(&self->regex, (char *) log->msg->data, 0, NULL, 0)) ^ c->comp;
 }
 
 struct filter_expr_node *make_filter_match(const char *re)
@@ -230,7 +231,7 @@ static int do_filter_prog(struct filter_expr_node *c,
 			  struct log_info *log)
 {
 	CAST(filter_expr_re, self, c);
-	return (log->program && !regexec(&self->regex, log->program->data, 0, NULL, 0)) ^ c->comp;
+	return (log->program && !regexec(&self->regex, (char *) log->program->data, 0, NULL, 0)) ^ c->comp;
 }
 
 struct filter_expr_node *make_filter_prog(const char *re)
@@ -263,9 +264,9 @@ static int do_filter_netmask(struct filter_expr_node *c,
        
 	if (log->saddr) {
 		CAST(inet_address_info, adrinf, log->saddr);
-		uint32_t host;
-		uint32_t netw;
-		uint32_t mask;
+		unsigned long host;
+		unsigned long netw;
+		unsigned long mask;
 
 		host = adrinf->sa.sin_addr.s_addr;
 		netw = self->network.s_addr;
