@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.32 2003/10/15 08:26:44 bazsi Exp $
+ * $Id: log.c,v 1.32.4.1 2004/01/13 18:08:02 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -46,7 +46,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 	unsigned char *src;
 	unsigned int left, pri, oldleft;
 	time_t now = time(NULL);
-	char *oldsrc;
+	unsigned char *oldsrc;
 	
 	src = data;
 	left = length;
@@ -95,10 +95,10 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 			
 			src[20] = 0;
 			memset(&tm, 0, sizeof(tm));
-			strptime(src, "%b %e %Y %H:%M:%S", &tm);
+			strptime((char *) src, "%b %e %Y %H:%M:%S", &tm);
 			tm.tm_isdst = -1;
 			lm->date = ol_string_alloc(16);
-			strftime(lm->date->data, 16, "%b %e %H:%M:%S", &tm);
+			strftime((char *) lm->date->data, 16, "%b %e %H:%M:%S", &tm);
 			lm->date->length--;
 			src[20] = ':';
 			src += 21;
@@ -118,7 +118,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
 			/* And also make struct time timestamp for the msg */
 			nowtm = localtime(&now);
 			memset(&tm, 0, sizeof(tm));
-			strptime(lm->date->data, "%b %e %H:%M:%S", &tm);
+			strptime((char *) lm->date->data, "%b %e %H:%M:%S", &tm);
 			tm.tm_isdst = -1;
 			tm.tm_year = nowtm->tm_year;
 			if (tm.tm_mon > nowtm->tm_mon + 1)
@@ -130,7 +130,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data, UINT8
         if (lm->date) {
 	        /* Expected format: hostname program[pid]: */
 	        /* Possibly: Message forwarded from hostname: ... */
-	        char *hostname_start = NULL;
+	        unsigned char *hostname_start = NULL;
 		int hostname_len = 0;
 		
 		while (left && *src == ' ') {
@@ -314,7 +314,7 @@ struct log_info *make_internal_message(UINT32 pri, UINT32 length, UINT8 *data)
 
 struct log_info *make_mark_message(void)
 {
-	struct log_info *self = make_internal_message(LOG_SYSLOG | LOG_NOTICE, 12, "--- MARK ---");
+	struct log_info *self = make_internal_message(LOG_SYSLOG | LOG_NOTICE, 12, (UINT8 *) "--- MARK ---");
 	self->flags |= LF_MARK;
 	return self;
 }
