@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.49 2003/09/24 14:02:31 bazsi Exp $
+ * $Id: main.c,v 1.49.4.2 2005/01/20 17:30:17 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -69,6 +69,7 @@ static void do_reread_config(struct callback *c)
 
 	switch (self->state) {
 	case -1:
+		self->backend->super.reloading = 1;
 		self->state++;
 		break;
 	case 0:
@@ -205,7 +206,8 @@ int main_loop(struct syslog_backend *backend)
 			CONFIG_DESTROY(backend->configuration, 0);
 			break;
 		}
-		if (reload_config) {
+		if (reload_config && r.state == 0) {
+		        /* reload initiated and callout started by SIGHUP finished, e.g. r.state == 0 */
 			backend->newconfig = make_syslog_config(cfgfilename, &backend->super);
 			if (backend->newconfig) {
 				
@@ -235,7 +237,7 @@ int main_loop(struct syslog_backend *backend)
 		}
 		if (sighuprecvd) {
 			sighuprecvd = 0;
-			if (!backend->super.reloading) {
+			if (!backend->super.reloading && !reload_config) {
 #if HAVE_RES_INIT
 				res_init();
 #endif
@@ -244,7 +246,6 @@ int main_loop(struct syslog_backend *backend)
 					set_error_stream(2, 0);
 					set_internal_cfg(NULL);
 				}
-				backend->super.reloading = 1;
 				reload_config = 1;
 				r.backend = backend;
 				r.state = -1;
@@ -425,6 +426,8 @@ int main(int argc, char **argv)
 #endif
 	gc_idle_threshold = 100;
 	gc_busy_threshold = 3000;
+	
+	tzset();
 
 	while ((opt = getopt_long(argc, argv, "sFf:p:dvhyVC:u:g:", syslog_ng_options, NULL)) != -1) {
 		switch (opt) {
